@@ -1,21 +1,21 @@
 /* gda-query-field-all.c
  *
- * Copyright (C) 2003 - 2006 Vivien Malerba
+ * Copyright (C) 2003 - 2007 Vivien Malerba
  *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License as
+ * This Library is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU Library General Public License as
  * published by the Free Software Foundation; either version 2 of the
  * License, or (at your option) any later version.
  *
- * This program is distributed in the hope that it will be useful,
+ * This Library is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ * Library General Public License for more details.
  *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
- * USA
+ * You should have received a copy of the GNU Library General Public
+ * License along with this Library; see the file COPYING.LIB.  If not,
+ * write to the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
+ * Boston, MA 02111-1307, USA.
  */
 
 #include "gda-query-field-all.h"
@@ -55,11 +55,12 @@ static gboolean    gda_query_field_all_load_from_xml (GdaXmlStorage *iface, xmlN
 /* Field interface */
 static void              gda_query_field_all_field_init      (GdaEntityFieldIface *iface);
 static GdaEntity         *gda_query_field_all_get_entity      (GdaEntityField *iface);
-static GdaDictType *gda_query_field_all_get_data_type   (GdaEntityField *iface);
+static GdaDictType *gda_query_field_all_get_dict_type   (GdaEntityField *iface);
 
 /* Renderer interface */
 static void            gda_query_field_all_renderer_init      (GdaRendererIface *iface);
-static gchar          *gda_query_field_all_render_as_sql   (GdaRenderer *iface, GdaParameterList *context, guint options, GError **error);
+static gchar          *gda_query_field_all_render_as_sql   (GdaRenderer *iface, GdaParameterList *context, 
+							    GSList **out_params_used, GdaRendererOptions options, GError **error);
 static gchar          *gda_query_field_all_render_as_str   (GdaRenderer *iface, GdaParameterList *context);
 
 /* Referer interface */
@@ -179,7 +180,7 @@ static void
 gda_query_field_all_field_init (GdaEntityFieldIface *iface)
 {
 	iface->get_entity = gda_query_field_all_get_entity;
-	iface->get_data_type = gda_query_field_all_get_data_type;
+	iface->get_dict_type = gda_query_field_all_get_dict_type;
 }
 
 static void
@@ -214,12 +215,14 @@ gda_query_field_all_class_init (GdaQueryFieldAllClass * class)
 	object_class->set_property = gda_query_field_all_set_property;
 	object_class->get_property = gda_query_field_all_get_property;
 	g_object_class_install_property (object_class, PROP_QUERY,
-					 g_param_spec_pointer ("query", "Query to which the field belongs", NULL, 
+					 g_param_spec_object ("query", "Query to which the field belongs", NULL, 
+                                                               GDA_TYPE_QUERY,
 							       (G_PARAM_READABLE | G_PARAM_WRITABLE | 
 								G_PARAM_CONSTRUCT_ONLY)));
 
 	g_object_class_install_property (object_class, PROP_TARGET_OBJ,
-					 g_param_spec_pointer ("target", "A pointer to a GdaQueryTarget", NULL, 
+					 g_param_spec_object ("target", "A pointer to a GdaQueryTarget", NULL,
+                                                               GDA_TYPE_QUERY_TARGET, 
 							       (G_PARAM_READABLE | G_PARAM_WRITABLE)));
 	g_object_class_install_property (object_class, PROP_TARGET_NAME,
 					 g_param_spec_string ("target_name", "Name or alias of a query target", NULL, NULL,
@@ -342,15 +345,14 @@ gda_query_field_all_set_property (GObject *object,
 				  GParamSpec *pspec)
 {
 	GdaQueryFieldAll *fall;
-	gpointer ptr;
 	const gchar *str;
 	guint id;
 
 	fall = GDA_QUERY_FIELD_ALL (object);
 	if (fall->priv) {
 		switch (param_id) {
-		case PROP_QUERY:
-			ptr = g_value_get_pointer (value);
+		case PROP_QUERY: {
+			GdaQuery* ptr = GDA_QUERY (g_value_get_object (value));
 			g_return_if_fail (GDA_IS_QUERY (ptr));
 			g_return_if_fail (gda_object_get_dict (GDA_OBJECT (ptr)) == gda_object_get_dict (GDA_OBJECT (fall)));
 
@@ -377,11 +379,13 @@ gda_query_field_all_set_property (GObject *object,
 			g_object_get (G_OBJECT (ptr), "field_serial", &id, NULL);
 			gda_query_object_set_int_id (GDA_QUERY_OBJECT (fall), id);
 			break;
-		case PROP_TARGET_OBJ:
-			ptr = g_value_get_pointer (value);
+                }
+		case PROP_TARGET_OBJ: {
+			GdaQueryTarget* ptr = GDA_QUERY_TARGET (g_value_get_object (value));
 			g_return_if_fail (GDA_IS_QUERY_TARGET (ptr));
 			gda_object_ref_set_ref_object (fall->priv->target_ref, GDA_OBJECT (ptr));
 			break;
+                }
 		case PROP_TARGET_NAME:
 			str = g_value_get_string (value);
 			gda_object_ref_set_ref_name (fall->priv->target_ref, GDA_TYPE_QUERY_TARGET, 
@@ -408,10 +412,10 @@ gda_query_field_all_get_property (GObject *object,
 	if (fall->priv) {
 		switch (param_id) {
 		case PROP_QUERY:
-			g_value_set_pointer (value, fall->priv->query);
+			g_value_set_object (value, G_OBJECT (fall->priv->query));
 			break;
 		case PROP_TARGET_OBJ:
-			g_value_set_pointer (value, gda_object_ref_get_ref_object (fall->priv->target_ref));
+			g_value_set_object (value, G_OBJECT (gda_object_ref_get_ref_object (fall->priv->target_ref)));
 			break;
 		case PROP_TARGET_NAME:
 		case PROP_TARGET_ID:
@@ -542,7 +546,7 @@ gda_query_field_all_get_entity (GdaEntityField *iface)
 }
 
 static GdaDictType *
-gda_query_field_all_get_data_type (GdaEntityField *iface)
+gda_query_field_all_get_dict_type (GdaEntityField *iface)
 {
 	g_return_val_if_fail (iface && GDA_IS_QUERY_FIELD_ALL (iface), NULL);
 	g_return_val_if_fail (GDA_QUERY_FIELD_ALL (iface)->priv, NULL);
@@ -566,13 +570,13 @@ gda_query_field_all_save_to_xml (GdaXmlStorage *iface, GError **error)
 
 	field = GDA_QUERY_FIELD_ALL (iface);
 
-	node = xmlNewNode (NULL, "gda_query_fall");
+	node = xmlNewNode (NULL, (xmlChar*)"gda_query_fall");
 	
 	str = gda_xml_storage_get_xml_id (iface);
-	xmlSetProp (node, "id", str);
+	xmlSetProp(node, (xmlChar*)"id", (xmlChar*)str);
 	g_free (str);
 
-	xmlSetProp (node, "name", gda_object_get_name (GDA_OBJECT (field)));
+	xmlSetProp(node, (xmlChar*)"name", (xmlChar*)gda_object_get_name (GDA_OBJECT (field)));
 
 	obj = NULL;
 	if (gda_object_ref_activate (field->priv->target_ref))
@@ -581,20 +585,20 @@ gda_query_field_all_save_to_xml (GdaXmlStorage *iface, GError **error)
 	if (obj) {
 		gchar *xmlid;
 		xmlid = gda_xml_storage_get_xml_id (GDA_XML_STORAGE (obj));
-		xmlSetProp (node, "target", xmlid);
+		xmlSetProp(node, (xmlChar*)"target", (xmlChar*)xmlid);
 	}
 	else {
 		const gchar *cstr;
 
 		cstr = gda_object_ref_get_ref_name (field->priv->target_ref, NULL, NULL);
 		if (cstr)
-			xmlSetProp (node, "target_name", cstr);
+			xmlSetProp(node, (xmlChar*)"target_name", (xmlChar*)cstr);
 	}
 
 	if (! gda_query_field_is_visible (GDA_QUERY_FIELD (field)))
-		xmlSetProp (node, "is_visible",  "f");
+		xmlSetProp(node, (xmlChar*)"is_visible",  (xmlChar*)"f");
 	if (gda_query_field_is_internal (GDA_QUERY_FIELD (field)))
-		xmlSetProp (node, "is_internal", "t");
+		xmlSetProp(node, (xmlChar*)"is_internal", (xmlChar*)"t");
 
 	return node;
 }
@@ -611,7 +615,7 @@ gda_query_field_all_load_from_xml (GdaXmlStorage *iface, xmlNodePtr node, GError
 	g_return_val_if_fail (node, FALSE);
 
 	field = GDA_QUERY_FIELD_ALL (iface);
-	if (strcmp (node->name, "gda_query_fall")) {
+	if (strcmp ((gchar*)node->name, "gda_query_fall")) {
 		g_set_error (error,
 			     GDA_QUERY_FIELD_ALL_ERROR,
 			     GDA_QUERY_FIELD_ALL_XML_LOAD_ERROR,
@@ -619,7 +623,7 @@ gda_query_field_all_load_from_xml (GdaXmlStorage *iface, xmlNodePtr node, GError
 		return FALSE;
 	}
 
-	prop = xmlGetProp (node, "id");
+	prop = (gchar*)xmlGetProp(node, (xmlChar*)"id");
 	if (prop) {
 		gchar *ptr, *tok;
 		ptr = strtok_r (prop, ":", &tok);
@@ -635,20 +639,20 @@ gda_query_field_all_load_from_xml (GdaXmlStorage *iface, xmlNodePtr node, GError
 		g_free (prop);
 	}
 
-	prop = xmlGetProp (node, "name");
+	prop = (gchar*)xmlGetProp(node, (xmlChar*)"name");
 	if (prop) {
 		gda_object_set_name (GDA_OBJECT (field), prop);
 		g_free (prop);
 	}
 
-	prop = xmlGetProp (node, "target");
+	prop = (gchar*)xmlGetProp(node, (xmlChar*)"target");
 	if (prop) {
 		target = TRUE;
 		gda_object_ref_set_ref_name (field->priv->target_ref, GDA_TYPE_QUERY_TARGET, REFERENCE_BY_XML_ID, prop);
 		g_free (prop);
 	}
 	else {
-		prop = xmlGetProp (node, "target_name");
+		prop = (gchar*)xmlGetProp(node, (xmlChar*)"target_name");
 		if (prop) {
 			target = TRUE;
 			gda_object_ref_set_ref_name (field->priv->target_ref, GDA_TYPE_QUERY_TARGET, REFERENCE_BY_NAME, prop);
@@ -656,13 +660,13 @@ gda_query_field_all_load_from_xml (GdaXmlStorage *iface, xmlNodePtr node, GError
 		}
 	}
 
-	prop = xmlGetProp (node, "is_visible");
+	prop = (gchar*)xmlGetProp(node, (xmlChar*)"is_visible");
 	if (prop) {
 		gda_query_field_set_visible (GDA_QUERY_FIELD (field), (*prop == 't') ? TRUE : FALSE);
 		g_free (prop);
 	}
 
-	prop = xmlGetProp (node, "is_internal");
+	prop = (gchar*)xmlGetProp(node, (xmlChar*)"is_internal");
 	if (prop) {
 		gda_query_field_set_internal (GDA_QUERY_FIELD (field), (*prop == 't') ? TRUE : FALSE);
 		g_free (prop);
@@ -686,7 +690,8 @@ gda_query_field_all_load_from_xml (GdaXmlStorage *iface, xmlNodePtr node, GError
  */
 
 static gchar *
-gda_query_field_all_render_as_sql (GdaRenderer *iface, GdaParameterList *context, guint options, GError **error)
+gda_query_field_all_render_as_sql (GdaRenderer *iface, GdaParameterList *context, 
+				   GSList **out_params_used, GdaRendererOptions options, GError **error)
 {
 	gchar *str = NULL;
 	GdaObject *base;
