@@ -206,7 +206,7 @@ list_datasource_info (TestConfig *config, xmlNodePtr parent, gchar *dsn)
 		GList *l;
 		
 		ul = xmlNewChild (parent, NULL, "ul", NULL);
-		xmlSetProp (ul, "class", "none");
+		xmlSetProp(ul, "class", (xmlChar*)"none");
 		for (l = keys; l != NULL; l = l->next) {
 			gchar *value;
 			gchar *key = (gchar *) l->data;
@@ -323,7 +323,7 @@ detail_provider (TestConfig *config, const gchar *provider)
 			td = xmlNewChild (tr, NULL, "td", tmp);
 			td = xmlNewChild (tr, NULL, "td", gda_object_get_name (GDA_OBJECT (params->data)));
 			td = xmlNewChild (tr, NULL, "td", 
-					  g_type_to_string (gda_parameter_get_g_type (GDA_PARAMETER (params->data))));
+					  gda_g_type_to_string (gda_parameter_get_g_type (GDA_PARAMETER (params->data))));
 
 			params = g_slist_next (params);
 		}
@@ -441,9 +441,6 @@ test_provider (TestConfig *config, HtmlFile *file, GdaServerProvider *provider,
 		{"begin_transaction", (GFunc) class->begin_transaction, FALSE},
 		{"commit_transaction", (GFunc) class->commit_transaction, FALSE},
 		{"rollback_transaction", (GFunc) class->rollback_transaction, FALSE},
-
-		{"create_blob", (GFunc) class->create_blob, FALSE},
-		{"fetch_blob", (GFunc) class->fetch_blob, FALSE},
 	};
 
 	g_assert (provider);
@@ -490,7 +487,7 @@ test_provider (TestConfig *config, HtmlFile *file, GdaServerProvider *provider,
 
 			td = xmlNewChild (tr, NULL, "td",  NULL);
 			ul = xmlNewChild (td, NULL, "ul",  NULL);
-			xmlSetProp (ul, "class", "none");
+			xmlSetProp(ul, "class", (xmlChar*)"none");
 
 			html_render_attribute_str (ul, "li", "provider_name", pinfo->provider_name);
 			html_render_attribute_bool (ul, "li", "is_case_insensitive", pinfo->is_case_insensitive);
@@ -525,14 +522,12 @@ test_provider (TestConfig *config, HtmlFile *file, GdaServerProvider *provider,
 					       "Updatable cursors",
 					       "Users",
 					       "Views",
-					       "XML queries"};
+					       "XML queries", NULL};
 
 		td = xmlNewChild (tr, NULL, "td",  NULL);
 		ul = xmlNewChild (td, NULL, "ul",  NULL);
-		xmlSetProp (ul, "class", "none");
-		for (feature=GDA_CONNECTION_FEATURE_AGGREGATES; 
-		     feature <= GDA_CONNECTION_FEATURE_XML_QUERIES;
-		     feature++) 
+		xmlSetProp(ul, "class", (xmlChar*)"none");
+		for (feature = GDA_CONNECTION_FEATURE_AGGREGATES; feature_name[feature] != NULL; feature++) 
 			html_render_attribute_bool (ul, "li", feature_name[feature],
 					       (class->supports_feature) (provider, cnc, feature));
 	}
@@ -808,9 +803,9 @@ test_provider (TestConfig *config, HtmlFile *file, GdaServerProvider *provider,
 			type = tested_types [i];
 
 			tr = xmlNewChild (table, NULL, "tr", NULL);
-			td = xmlNewChild (tr, NULL, "th", g_type_to_string (type));
+			td = xmlNewChild (tr, NULL, "th", gda_g_type_to_string (type));
 			
-			tmp = g_strdup_printf ("/providers/%p/%s", provider, g_type_to_string (type));
+			tmp = g_strdup_printf ("/providers/%p/%s", provider, gda_g_type_to_string (type));
 			html_declare_node_own (HTML_CONFIG (config), tmp, td);
 
 			dh = (class->get_data_handler) (provider, cnc, type, NULL);
@@ -832,7 +827,7 @@ test_provider (TestConfig *config, HtmlFile *file, GdaServerProvider *provider,
 					}
 					else {
 						td = xmlNewChild (tr, NULL, "td", "none");
-						xmlSetProp (td, "class", "null");
+						xmlSetProp(td, "class", (xmlChar*)"null");
 					}
 				}
 			}
@@ -847,7 +842,7 @@ test_provider (TestConfig *config, HtmlFile *file, GdaServerProvider *provider,
 				if (dh && !dbms_type)
 					html_mark_node_error (HTML_CONFIG (config), td);
 				else
-					xmlSetProp (td, "class", "null");
+					xmlSetProp(td, "class", (xmlChar*)"null");
 			}
 			else
 				td = xmlNewChild (tr, NULL, "td", "");
@@ -1195,7 +1190,7 @@ real_test_data_handler (TestConfig *config, GdaDataHandler *dh, GType type,
 		gchar *str;
 		tr = xmlNewChild (table1, NULL, "tr", NULL);
 
-		td = xmlNewChild (tr, NULL, "td", g_type_to_string (type));
+		td = xmlNewChild (tr, NULL, "td", gda_g_type_to_string (type));
 
 		tmp = gda_value_stringify (value);
 		str = g_strdup_printf (_("%s (init value)"), tmp);
@@ -1219,7 +1214,7 @@ real_test_data_handler (TestConfig *config, GdaDataHandler *dh, GType type,
 		tr = xmlNewChild (table1, NULL, "tr", NULL);
 		value = (GValue *) (list->data);
 
-		td = xmlNewChild (tr, NULL, "td", g_type_to_string (type));
+		td = xmlNewChild (tr, NULL, "td", gda_g_type_to_string (type));
 
 		tmp = gda_value_stringify (value);
 		td = xmlNewChild (tr, NULL, "td", tmp);
@@ -1244,7 +1239,7 @@ real_test_data_handler (TestConfig *config, GdaDataHandler *dh, GType type,
 		sql = sql_values[i].str;
 		while (sql) {
 			tr = xmlNewChild (table2, NULL, "tr", "\n");
-			td = xmlNewChild (tr, NULL, "td", g_type_to_string (type));
+			td = xmlNewChild (tr, NULL, "td", gda_g_type_to_string (type));
 			td = xmlNewChild (tr, NULL, "td", sql);
 
 			value = gda_data_handler_get_value_from_sql (dh, sql, type);
@@ -1266,7 +1261,7 @@ real_test_data_handler (TestConfig *config, GdaDataHandler *dh, GType type,
 			}
 			else {
 				td = xmlNewChild (tr, NULL, "td", "NULL");
-				xmlSetProp (td, "class", "null");
+				xmlSetProp(td, "class", (xmlChar*)"null");
 			}
 
 			i++;
@@ -1282,7 +1277,7 @@ real_test_data_handler (TestConfig *config, GdaDataHandler *dh, GType type,
 		sql = str_values[i].str;
 		while (sql) {
 			tr = xmlNewChild (table3, NULL, "tr", NULL);
-			td = xmlNewChild (tr, NULL, "td", g_type_to_string (type));
+			td = xmlNewChild (tr, NULL, "td", gda_g_type_to_string (type));
 			td = xmlNewChild (tr, NULL, "td", sql);
 
 			value = gda_data_handler_get_value_from_str (dh, sql, type);
@@ -1310,7 +1305,7 @@ real_test_data_handler (TestConfig *config, GdaDataHandler *dh, GType type,
 			}
 			else {
 				td = xmlNewChild (tr, NULL, "td", "NULL");
-				xmlSetProp (td, "class", "null");
+				xmlSetProp(td, "class", (xmlChar*)"null");
 			}
 
 			i++;
